@@ -20,7 +20,7 @@ def __call_function_based_on_re(**kwargs) -> bool:
         # look through the re to get required info
         mod_name = tag_match.groupdict()['mod_name']
         function_name = tag_match.groupdict()['function_name']
-        module = importlib.import_module('trigger', mod_name)
+        module = importlib.import_module(f'trigger.{mod_name}')
 
         # if valid info call the function
         if hasattr(module, function_name):
